@@ -20,7 +20,7 @@ def start_example_task(args=None, test=False):
     argument_objs = _build_arguments()
 
     task_name, arguments = ComplexArguments(argument_objs).parse(args)
-    arguments.taskArgs.model_args.unit_test = test
+    if test: arguments.model_args.unit_test = test
     log.info("Start Example Task:{}, with arguments:{}".format(task_name, str(arguments.taskArgs)))
     task_action = arguments.runArgs.action
     task_instance = TASKS[task_name](arguments.taskArgs)
